@@ -2,7 +2,7 @@ import copy
 import sys
 import uuid
 
-from collections import namedtuple, OrderedDict, Hashable
+from collections import namedtuple, OrderedDict
 
 from six import with_metaclass
 
@@ -43,13 +43,31 @@ _PREDEFINED_FUNCTIONS = [['size',], ['reverse',], ['head',], ['tail',],
     ['E', 'e'], ['toString',], ['replace',], ['substring',], ['left',],
     ['right',], ['trim',], ['ltrim',], ['toUpper',], ['toLower',],
     ['SPLIT', 'split',],['exists',], ['distinct', 'distinct', True],
-    ['MAX', 'max']]
+    ['MAX', 'max'], ['labels']]
 RELATIONSHIP_DIRECTIONS = {
     '-': 'undirected',
     '>': 'out',
     '<': 'in',
 }
 
+QUOTES = {
+    'label': '`',
+    'property': '`',
+    'map_key': '`',
+}
+
+def quote(mark, val):
+    return '{}{}{}'.format(mark, val, mark)
+
+def quote_label(val):
+    return quote(QUOTES['label'], val)
+
+def quote_propery(val):
+    return quote(QUOTES['property'], val)
+
+def quote_map_key(val):
+    return quote(QUOTES['map_key'], val)
+
 
 def create_function(name, attrs=None, func_raw=False):
     """
@@ -201,11 +219,6 @@ class Params(object):
         bind = True
         is_pypher = False
 
-        # we want None values to be assigned as the keyword NULL in the
-        # resulting Cypher
-        # if value is None:
-        #     value = __.NULL
-
         if isinstance(value, Param):
             name = value.name
             value = value.value
@@ -685,7 +698,8 @@ class Property(Statement):
         super(Property, self).__init__(name=name)
 
     def __unicode__(self):
-        return '.`{}`'.format(self.name)
+        prop = quote_propery(self.name)
+        return '.{}'.format(prop)
 
 
 class Label(Statement):
@@ -732,7 +746,7 @@ class Label(Statement):
         if not self.labels:
             return ''
 
-        labels = ['`{}`'.format(a) for a in self.labels]
+        labels = ['{}'.format(quote_label(a)) for a in self.labels]
         labels = ('{}'.format(self.operator)).join(labels)
 
         return ':{labels}'.format(labels=labels)
@@ -985,7 +999,8 @@ class Map(_BaseLink):
         kwargs = OrderedDict(sorted(self.kwargs.items()))
 
         for k, val in kwargs.items():
-            pair = '`{}`: {}'.format(k, prep_value(val, k))
+            key = quote_map_key(k)
+            pair = '{}: {}'.format(key, prep_value(val, k))
             body.append(pair)
 
         body = ', '.join(body)
@@ -1023,10 +1038,6 @@ class Operator(_BaseLink):
         return self._value
 
     def _set_value(self, value):
-        # None should result to NULL
-        if value is None:
-            value = __.NULL
-
         self._value = value
 
         return self
@@ -1056,7 +1067,8 @@ class Operator(_BaseLink):
                             param = self.bind_param(v)
                             v = param.placeholder
 
-                        new.append('`{}`: {}'.format(k, v))
+                        key = quote_map_key(k)
+                        new.append('{}: {}'.format(key, v))
 
                     return '{{{}}}'.format(', '.join(new))
                 else:
@@ -1152,8 +1164,9 @@ class Entity(_BaseLink):
         for k, v in self._properties.items():
             name = self.params.param_name(k)
             param = self.bind_param(value=v, name=name)
+            key = quote_propery(k)
 
-            properties.append('`{key}`: {val}'.format(key=k,
+            properties.append('{key}: {val}'.format(key=key,
                 val=param.placeholder))
 
         if properties:
